@@ -64,7 +64,7 @@ function dir_copy($dir_name, $new_dir)
 //-----------------------------------------------------------
 
 //(元html,対象タグ,変換関数,変換関数パラメータ) -> 変換後html,[変換関数の戻り値]
-function pgetParseHtml($srcHtml,$tag,$converter,$convparam) {
+function pgetParseHtml($srcHtml,$tag,$converter,$convparam,$url) {
   $curHtml = $srcHtml;
   $tagPairs = array();
   $convHtml = "";
@@ -79,7 +79,7 @@ function pgetParseHtml($srcHtml,$tag,$converter,$convparam) {
       $restHtml = substr($curHtml, $tagclose + 1 );
 
       $converted = $target;
-      if( $ret = call_user_func($converter, $target, $convparam) ) {
+      if( $ret = call_user_func($converter, $target, $convparam, $url) ) {
         //変換成功
         $converted = $ret[0];
         array_push($tagPairs, $ret);
@@ -102,7 +102,26 @@ function cnvNone($src,$convparam) {
 }
 
 //サムネの抜き出しとURL書き換えを行う
-function cnvThumb($src,$convparam) {
+function cnvThumb($src,$convparam,$url) {
+  // 避難所用
+  $reg = "/(.*)src=[\"\'](\/.*\/thumb\/[^\"^\']*)[\"\'](.*)/i";
+  $matches = array();
+  if(preg_match($reg, $src, $matches) == 1){
+    $fname = str_replace("/","_",$matches[2]);
+    $mc = array();
+    if(preg_match("/([^\/]+)$/i", $matches[2], $mc) == 1) {
+      $fname = $mc[1];
+    }
+    $host = "www.2chan.net";
+    if(preg_match("/https?:\/\/([^\/]+).*/", $url, $hm) == 1){
+      $host = $hm[1];
+    }
+    return array($matches[1] . "src=\"" . $convparam . $fname . "\"" . $matches[3]
+                 ,$src,
+                 $host."/".$matches[2],
+                 $convparam . $fname );
+  }
+  // 通常のふたば用
   $reg = "/(.*)src=[\"\']http:\/\/(.*\.2chan.net\/.*\/thumb\/[^\"^\']*)[\"\'](.*)/i";
   $matches = array();
   if(preg_match($reg, $src, $matches) == 1){
@@ -120,7 +139,30 @@ function cnvThumb($src,$convparam) {
 }
 
 //リンク先画像のURL書き換えを行う
-function cnvLink($src,$convparam) {
+function cnvLink($src,$convparam,$url) {
+  // 避難所用
+  $reg = "/(.*)href=[\"\'](\/.*\/src\/[^\"^\']*)[\"\'](.*)/i";
+  $matches = array();
+  if(preg_match($reg, $src, $matches) == 1){
+    $fname = str_replace("/","_",$matches[2]);
+    $mc = array();
+    if(preg_match("/([^\/]+)$/i", $matches[2], $mc) == 1) {
+      $fname = $mc[1];
+    }
+    $lbparam = "";
+    if(useLightBox() && isImageFileExt($fname)) {
+      $lbparam = ' rel="lightbox"';
+    }
+    $host = "www.2chan.net";
+    if(preg_match("/https?:\/\/([^\/]+).*/", $url, $hm) == 1){
+      $host = $hm[1];
+    }
+    return array($matches[1] . "href=\"" . $convparam . $fname . "\"" . $lbparam . $matches[3]
+                 ,$src,
+                 $host."/".$matches[2],
+                 $convparam . $fname );
+  }
+  // 通常のふたば用
   $reg = "/(.*)href=[\"\']http:\/\/(.*\.2chan.net\/.*\/src\/[^\"^\']*)[\"\'](.*)/i";
   $matches = array();
   if(preg_match($reg, $src, $matches) == 1){
@@ -566,16 +608,16 @@ function cust_pget($url,$storeDir,
   }
 
   //base href除去
-  $result = pgetParseHtml($srcHtml, 'base', 'cnvNone', "");
+  $result = pgetParseHtml($srcHtml, 'base', 'cnvNone', "", $url);
   $convHtml = $result[0];
 
   //aタグの置換
-  $result = pgetParseHtml($convHtml, 'a', 'cnvLink', _PGET_IMG_DIR_);
+  $result = pgetParseHtml($convHtml, 'a', 'cnvLink', _PGET_IMG_DIR_, $url);
   $convHtml = $result[0];
   $convResults =array_merge ( $convResults,$result[1]);
 
   //imgタグの置換
-  $result = pgetParseHtml($convHtml, 'img', 'cnvThumb', _PGET_THUMB_DIR_);
+  $result = pgetParseHtml($convHtml, 'img', 'cnvThumb', _PGET_THUMB_DIR_, $url);
   $convHtml = $result[0];
   $convResults =array_merge ( $convResults,$result[1]);
 
@@ -604,7 +646,7 @@ function cust_pget($url,$storeDir,
       '<span class="thre"',$convHtml);
     
     $convHtml = pgetRmTag($convHtml, 'div', true);
-    $result   = pgetParseHtml($convHtml, '/div', 'cnvNone', "");
+    $result   = pgetParseHtml($convHtml, '/div', 'cnvNone', "", $url);
     $convHtml = $result[0];
     
     $convHtml = pgetRmTag($convHtml, 'iframe', true);
